@@ -144,7 +144,7 @@ extensions = {
 		end;
 
 		["1000"] = function()
-			app.goto("default", "s", 1)
+			app.goto("demo", "s", 1)
 		end;
 
 		["1234"] = function()
@@ -194,6 +194,15 @@ extensions = {
 		include = {"demo"};
 	};
 
+	public = {
+		-- ATTENTION: If your Asterisk is connected to the internet and you do
+		-- not have allowguest=no in sip.conf, everybody out there may use your
+		-- public context without authentication.  In that case you want to
+		-- double check which services you offer to the world.
+		--
+		include = {"demo"};
+	};
+
 	["local"] = {
 		["_NXXXXXX"] = outgoing_local;
 	};
